@@ -27,31 +27,49 @@
 #'     # Download clinical data from XML
 #'     query <- GDCquery(project = "TCGA-COAD", data.category = "Clinical")
 #'     GDCdownload(query, files.per.chunk = 200)
-#'     query <- GDCquery(project = "TARGET-AML",
-#'                   data.category = "Transcriptome Profiling",
-#'                   data.type = "miRNA Expression Quantification",
-#'                   workflow.type = "BCGSC miRNA Profiling",
-#'                   barcode = c("TARGET-20-PARUDL-03A-01R","TARGET-20-PASRRB-03A-01R"))
+#'     query <- GDCquery(
+#'         project = "TARGET-AML",
+#'         data.category = "Transcriptome Profiling",
+#'         data.type = "miRNA Expression Quantification",
+#'         workflow.type = "BCGSC miRNA Profiling",
+#'         barcode = c("TARGET-20-PARUDL-03A-01R","TARGET-20-PASRRB-03A-01R")
+#'     )
 #'     # data will be saved in:
 #'     # example_data_dir/TARGET-AML/harmonized/Transcriptome_Profiling/miRNA_Expression_Quantification
 #'     GDCdownload(query, method = "client", directory = "example_data_dir")
-#'     acc.gbm <- GDCquery(project =  c("TCGA-ACC","TCGA-GBM"),
-#'                         data.category = "Transcriptome Profiling",
-#'                         data.type = "Gene Expression Quantification",
-#'                         workflow.type = "HTSeq - Counts")
-#'     GDCdownload(acc.gbm, method = "api", directory = "example", files.per.chunk = 50)
+#'     acc.gbm <- GDCquery(
+#'         project =  c("TCGA-ACC","TCGA-GBM"),
+#'         data.category = "Transcriptome Profiling",
+#'         data.type = "Gene Expression Quantification",
+#'         workflow.type = "STAR - Counts"
+#'     )
+#'     GDCdownload(
+#'        query = acc.gbm,
+#'        method = "api",
+#'        directory = "example",
+#'        files.per.chunk = 50
+#'    )
 #' }
 #' @return Shows the output from the GDC transfer tools
-GDCdownload <- function(query,
-                        token.file,
-                        method = "api",
-                        directory = "GDCdata",
-                        files.per.chunk = NULL) {
+#' @author Tiago Chedraoui Silva
+GDCdownload <- function(
+    query,
+    token.file,
+    method = "api",
+    directory = "GDCdata",
+    files.per.chunk = NULL
+) {
     isServeOK()
-    if(missing(query)) stop("Please set query argument")
+    if (missing(query)) stop("Please set query argument")
 
-    if(!(method %in% c("api","client"))) stop("method arguments possible values are: 'api' or 'client'")
-    if(length(unique(getResults(query)$data_type)) > 1) stop("We can only download one data type. Please use data.type argument in GDCquery to filter results.")
+    if (!(method %in% c("api","client"))) {
+        stop("method arguments possible values are: 'api' or 'client'")
+    }
+
+    if (length(unique(getResults(query)$data_type)) > 1) {
+        print(knitr::kable(sort(unique(getResults(query)$data_type)),col.names = "data_type in query"))
+        stop("We can only download one data type. Please use data.type argument in GDCquery to filter results.")
+    }
 
     source <- ifelse(query$legacy,"legacy","harmonized")
 
@@ -64,9 +82,12 @@ GDCdownload <- function(query,
 
         manifest <- getManifest(query.aux)
 
-        path <- unique(file.path(proj, source,
-                                 gsub(" ","_", results$data_category),
-                                 gsub(" ","_",results$data_type)))
+        path <- unique(
+            file.path(
+                proj, source,
+                gsub(" ","_", results$data_category),
+                gsub(" ","_",results$data_type))
+        )
         path <- file.path(directory, path)
 
         # Check if the files were already downloaded by this package
@@ -75,8 +96,9 @@ GDCdownload <- function(query,
         # There is a bug in the API, if the files has the same name it will not download correctly
         # so method should be set to client if there are files with duplicated names
         # However for clinical XML recurrent and primary are the same file. So we will ignore that case
-        if(nrow(manifest) > length(unique(manifest$filename))) method <- "client"
-        if(nrow(manifest) != 0 & method == "client") {
+        if (nrow(manifest) > length(unique(manifest$filename))) method <- "client"
+
+        if (nrow(manifest) != 0 & method == "client") {
             # There exists two options to download the data, using the query or using a manifest file
             # The second option was created to let users use legacy data or the API to search
 
@@ -85,10 +107,16 @@ GDCdownload <- function(query,
 
             # Using the query argument we will organize the files to the user
             # Creates a file with the gdc manifest format
-            write_delim(manifest,"gdc_manifest.txt",delim = "\t")
+            readr::write_delim(manifest,"gdc_manifest.txt",delim = "\t")
 
-            cmd <- paste0(gdc.client.bin, " download -m gdc_manifest.txt")
+            readr::write_delim(manifest,"gdc_client_configuration.dtt",delim = "\t")
+            readr::write_lines(
+                c("[download]","retry_amount = 6",paste0("dir =",path)),
+                file = "gdc_client_configuration.dtt"
+            )
+            cmd <- paste0(gdc.client.bin, " download -m gdc_manifest.txt --config gdc_client_configuration.dtt")
 
+            dir.create(path,recursive = TRUE,showWarnings = FALSE)
             if(!missing(token.file)) cmd <- paste0(cmd," -t ", token.file)
 
             # Download all the files in the manifest using gdc client
@@ -99,29 +127,38 @@ GDCdownload <- function(query,
                 system(cmd)
             }, warning = function(w) {
             }, error = function(e) {
-            }, finally = {
-                # moving the file to make it more organized
-                for(i in manifest$id) move(i,file.path(path,i))
             })
 
         } else if (nrow(manifest) != 0 & method =="api"){
             if(nrow(manifest) > 1) {
                 name <- paste0(gsub(" |:","_",date()),".tar.gz")
                 unlink(name)
-                message(paste0("GDCdownload will download ", nrow(manifest), " files. A total of " ,
-                               humanReadableByteCount(sum(as.numeric(manifest$size)))))
+                message(
+                    paste0(
+                        "GDCdownload will download ", nrow(manifest), " files. A total of " ,
+                        humanReadableByteCount(sum(as.numeric(manifest$size)))
+                    )
+                )
             } else {
                 # case with one file only. This is not at tar.gz
                 name <- manifest$filename
-                message(paste0("GDCdownload will download: ",
-                               humanReadableByteCount(sum(as.numeric(manifest$size)))))
+                message(
+                    paste0(
+                        "GDCdownload will download: ",
+                        humanReadableByteCount(sum(as.numeric(manifest$size)))
+                    )
+                )
             }
 
-            server <- ifelse(query$legacy,"https://api.gdc.cancer.gov/legacy/data/", "https://api.gdc.cancer.gov/data/")
+            server <- ifelse(
+                query$legacy,
+                "https://api.gdc.cancer.gov/legacy/data/",
+                "https://api.gdc.cancer.gov/data/"
+            )
 
-            if(is.null(files.per.chunk) & sum(as.numeric(manifest$size)) > 10^9) {
+            if (is.null(files.per.chunk) & sum(as.numeric(manifest$size)) > 10^9) {
                 message("The total size of files is big. We will download files in chunks")
-                files.per.chunk <- floor(10^9/mean(as.numeric(manifest$size)))
+                files.per.chunk <- floor(10^9 / mean(as.numeric(manifest$size)))
             }
 
             if(is.null(files.per.chunk)) {
@@ -159,34 +196,47 @@ GDCdownload <- function(query,
 #' @param query A query for GDCquery function
 #' @param save Write Manifest to a txt file (tab separated)
 #' @examples
-#' query <- GDCquery(project = "TARGET-AML",
-#'                   data.category = "Transcriptome Profiling",
-#'                   data.type = "Gene Expression Quantification",
-#'                   workflow.type = "HTSeq - Counts",
-#'                   barcode = c("TARGET-20-PADZCG-04A-01R","TARGET-20-PARJCR-09A-01R"))
+#' query <- GDCquery(
+#'   project = "TARGET-AML",
+#'   data.category = "Transcriptome Profiling",
+#'   data.type = "Gene Expression Quantification",
+#'   workflow.type = "STAR - Counts",
+#'   barcode = c("TARGET-20-PADZCG-04A-01R","TARGET-20-PARJCR-09A-01R")
+#'  )
 #' getManifest(query)
 #' @export
 getManifest <- function(query, save = FALSE) {
+
     manifest <- query$results[[1]][,c("file_id","file_name","md5sum","file_size","state")]
     colnames(manifest) <- c("id","filename","md5","size","state")
     if(save)  {
         fname <- "gdc_manifest.txt"
-        write_delim(manifest,fname,delim = "\t")
+        readr::write_delim(manifest,fname,delim = "\t")
         file <- file.path(getwd(),fname)
         message("Manifest saved as: ", file)
     }
     return(manifest)
 }
 
-GDCdownload.by.chunk <- function(server, manifest, name, path, step){
+GDCdownload.by.chunk <- function(
+    server = "https://api.gdc.cancer.gov/data/",
+    manifest,
+    name = "TCGAbiolinks_download",
+    path = ".",
+    step = 1
+){
     for(idx in 0:ceiling(nrow(manifest)/step - 1)){
         end <- ifelse(((idx + 1) * step) > nrow(manifest), nrow(manifest),((idx + 1) * step))
         manifest.aux <- manifest[((idx * step) + 1):end,]
         size <- humanReadableByteCount(sum(as.numeric(manifest.aux$size)))
-        name.aux <- gsub(".tar",paste0("_",idx,".tar"),name)
-        message(paste0("Downloading chunk ", idx + 1, " of ", ceiling(nrow(manifest)/step) ,
-                       " (", nrow(manifest.aux)," files, size = ", size,") ",
-                       "as ", name.aux))
+        name.aux <- gsub("\\.tar",paste0("_",idx,".tar"),name)
+        message(
+            paste0(
+                "Downloading chunk ", idx + 1, " of ", ceiling(nrow(manifest)/step) ,
+                " (", nrow(manifest.aux)," files, size = ", size,") ",
+                "as ", name.aux
+            )
+        )
         repeat {
             ret <- GDCdownload.aux(server, manifest.aux, name.aux, path)
             if(ret == 1) break
@@ -194,22 +244,30 @@ GDCdownload.by.chunk <- function(server, manifest, name, path, step){
     }
 }
 
-GDCdownload.aux <- function(server, manifest, name, path){
+GDCdownload.aux <- function(
+    server = "https://api.gdc.cancer.gov/data/",
+    manifest,
+    name = "TCGAbiolinks_download",
+    path = "."
+){
     result = tryCatch({
-        bin <- getURL(server,
-                      POST,
-                      body =  list(ids=list(manifest$id)),
-                      encode = "json",
-                      progress())
+        bin <- getURL(
+            server,
+            POST,
+            body =  list(ids=list(manifest$id)),
+            encode = "json",
+            progress()
+        )
         if(bin[[2]] == "405"){
             message("ERROR accessing GDC. Trying again...")
             bin <- getURL("https://api.gdc.cancer.gov/data/",
                           POST,
                           body =  list(ids=list(manifest$id)),
                           encode = "json",
-                          progress())
+                          progress()
+            )
         }
-        writeBin(getURL(bin,content, as= "raw",encoding = "UTF-8"), name)
+        writeBin(getURL(bin,content, as = "raw",encoding = "UTF-8"), name)
 
         if(nrow(manifest) > 1) {
             success <- untar(name)
@@ -235,7 +293,9 @@ GDCdownload.aux <- function(server, manifest, name, path){
             if(nrow(manifest) > 1) {
                 move(file,file.path(path,file))
             }
-            if(nrow(manifest) == 1) move(file,file.path(path,id,file))
+            if(nrow(manifest) == 1) {
+                move(file,file.path(path,id,file))
+            }
         }
         return(1)
     }, warning = function(w) {
@@ -244,9 +304,14 @@ GDCdownload.aux <- function(server, manifest, name, path){
         unlink(name) # remove tar
         return(-1)
     })
-    if(result == -1) stop(paste0("There was an error in the download process (we might had a connection problem with GDC server).",
-                                 "\nPlease run this function it again.",
-                                 "\nTry using method = `client` or setting files.per.chunk to a small number."))
+    if(result == -1) {
+        stop(
+            paste0(
+                "There was an error in the download process (we might had a connection problem with GDC server).",
+                "\nPlease run this function it again.",
+                "\nTry using method = `client` or setting files.per.chunk to a small number.")
+        )
+    }
     message("Download completed")
 }
 
@@ -303,8 +368,10 @@ GDCclientInstall <- function(){
 checkAlreadyDownloaded <- function(path,manifest){
     files2Download <- !(file.exists(file.path(path,manifest$id,manifest$filename)) | file.exists(file.path(path,manifest$filename)))
     if (any(files2Download == FALSE)) {
-        message("Of the ", nrow(manifest), " files for download ",
-                table(files2Download)["FALSE"] , " already exist.")
+        message(
+            "Of the ", nrow(manifest), " files for download ",
+            table(files2Download)["FALSE"] , " already exist."
+        )
         if (any(files2Download == TRUE)) message("We will download only those that are missing ones.")
     }
     return(manifest[files2Download,])
