@@ -51,16 +51,20 @@ getGDCInfo <- function(){
 }
 
 checkProjectInput <- function(project){
+
     projects <- getGDCprojects()
+
     if(missing(project)) {
-        print(knitr::kable(projects[,c(7,9)]))
+        print(knitr::kable(projects[,c("id","name")]))
         stop("Please set a project argument from the column id above")
     }
-    for(proj in project)
-        if(!(proj %in% projects$project_id)) {
-            print(knitr::kable(projects[,c(7,9)]))
+
+    for(proj in project) {
+        if( !(proj %in% projects$project_id)) {
+            print(knitr::kable(projects[,c("id","name")]))
             stop("Please set a valid project argument from the column id above. Project ", proj, " was not found.")
         }
+    }
 }
 
 checkLegacyPlatform <- function(project,data.category, legacy = FALSE){
@@ -111,6 +115,7 @@ checkDataTypeInput <- function(legacy, data.type){
                               "Clinical data",
                               "Copy number variation",
                               "ABI sequence trace",
+                              "Protein Expression Quantification",
                               "Biospecimen data",
                               "Simple somatic mutation",
                               "Bisulfite sequence alignment",
@@ -125,14 +130,18 @@ checkDataTypeInput <- function(legacy, data.type){
     } else {
         harmonized.data.type <- c(
             "Aggregated Somatic Mutation",
+            "Aligned Reads",
             "Gene Expression Quantification",
             "Raw CGI Variant",
             "Methylation Beta Value",
+            "Differential Gene Expression",
             "Splice Junction Quantification",
+            "Protein Expression Quantification",
             "Annotated Somatic Mutation",
             "Raw Simple Somatic Mutation",
             "Masked Somatic Mutation",
             "Copy Number Segment",
+            "Masked Intensities",
             "Allele-specific Copy Number Segment",
             "Masked Copy Number Segment",
             "Isoform Expression Quantification",
@@ -142,6 +151,7 @@ checkDataTypeInput <- function(legacy, data.type){
             "Gene Level Copy Number Scores",
             "Protein Expression Quantification",
             "Clinical Supplement",
+            "Single Cell Analysis",
             "Masked Somatic Mutation",
             "Slide Image")
         if(!data.type %in% harmonized.data.type) {
@@ -590,23 +600,36 @@ get.cnv <- function(project, genes){
     return(cnv.annotation)
 }
 
-get.mutation <- function(project,
-                         genes,
-                         pipeline = pipeline,
-                         mutant_variant_classification = c("Frame_Shift_Del",
-                                                           "Frame_Shift_Ins",
-                                                           "Missense_Mutation",
-                                                           "Nonsense_Mutation",
-                                                           "Splice_Site",
-                                                           "In_Frame_Del",
-                                                           "In_Frame_Ins",
-                                                           "Translation_Start_Site",
-                                                           "Nonstop_Mutation")){
+get.mutation <- function(
+        project,
+        genes,
+        mutant_variant_classification = c(
+            "Frame_Shift_Del",
+            "Frame_Shift_Ins",
+            "Missense_Mutation",
+            "Nonsense_Mutation",
+            "Splice_Site",
+            "In_Frame_Del",
+            "In_Frame_Ins",
+            "Translation_Start_Site",
+            "Nonstop_Mutation"
+        )){
     if(missing(project)) stop("Argument project is missing")
     if(missing(genes)) stop("Argument genes is missing")
 
     # Get mutation annotation file
-    maf <- GDCquery_Maf(gsub("TCGA-","",project),pipelines = pipeline)
+    library(maftools)
+    library(dplyr)
+    query <- GDCquery(
+        project = project,
+        data.category = "Simple Nucleotide Variation",
+        access = "open",
+        legacy = FALSE,
+        data.type = "Masked Somatic Mutation",
+        workflow.type = "Aliquot Ensemble Somatic Variant Merging and Masking"
+    )
+    GDCdownload(query)
+    maf <- GDCprepare(query)
 
     message(paste0("Consindering only the mutant_variant_classification mutations: \n o ",
                    paste(mutant_variant_classification, collapse = "\n o ")))
@@ -645,17 +668,19 @@ get.mutation <- function(project,
 
     return(mut)
 }
-get.mut.gistc <- function(project,
-                          genes,
-                          mut.pipeline,
-                          mutant_variant_classification) {
+get.mut.gistc <- function(
+        project,
+        genes,
+        mutant_variant_classification
+) {
 
     if(missing(project)) stop("Argument project is missing")
     if(missing(genes)) stop("Argument genes is missing")
-    mut <- get.mutation(project,
-                        genes,
-                        pipeline = mut.pipeline,
-                        mutant_variant_classification =  mutant_variant_classification )
+    mut <- get.mutation(
+        project,
+        genes,
+        mutant_variant_classification =  mutant_variant_classification
+    )
     cnv <- get.cnv(project, genes)
     if(!is.null(mut) & !is.null(cnv)) {
         annotation <- merge(mut, cnv, by = 0 , sort = FALSE,all=TRUE)
@@ -671,25 +696,31 @@ get.mut.gistc <- function(project,
     }
     return(NULL)
 }
-get.mut.gistc.information <- function(df,
-                                      project,
-                                      genes,
-                                      mut.pipeline = "mutect2",
-                                      mutant_variant_classification = c("Frame_Shift_Del",
-                                                                        "Frame_Shift_Ins",
-                                                                        "Missense_Mutation",
-                                                                        "Nonsense_Mutation",
-                                                                        "Splice_Site",
-                                                                        "In_Frame_Del",
-                                                                        "In_Frame_Ins",
-                                                                        "Translation_Start_Site",
-                                                                        "Nonstop_Mutation")) {
+get.mut.gistc.information <- function(
+        df,
+        project,
+        genes,
+        mutant_variant_classification = c(
+            "Frame_Shift_Del",
+            "Frame_Shift_Ins",
+            "Missense_Mutation",
+            "Nonsense_Mutation",
+            "Splice_Site",
+            "In_Frame_Del",
+            "In_Frame_Ins",
+            "Translation_Start_Site",
+            "Nonstop_Mutation"
+        )
+) {
     order <- rownames(df)
     for(i in genes) if(!tolower(i) %in% tolower(EAGenes$Gene)) message(paste("Gene not found:", i))
-    info <- as.data.frame(get.mut.gistc(project,
-                                        genes,
-                                        mut.pipeline = mut.pipeline,
-                                        mutant_variant_classification = mutant_variant_classification))
+    info <- as.data.frame(
+        get.mut.gistc(
+            project,
+            genes,
+            mutant_variant_classification = mutant_variant_classification
+        )
+    )
     if(is.null(info)) return(df)
     info$aux <- rownames(info)
     df$aux <- substr(df$barcode,1,15)
@@ -730,11 +761,13 @@ print.header <- function(text, type ="section"){
 #' @export
 #' @return Table with query results
 #' @examples
-#' query <- GDCquery(project = "TCGA-GBM",
-#'                   data.category = "Transcriptome Profiling",
-#'                   data.type = "Gene Expression Quantification",
-#'                   workflow.type = "HTSeq - Counts",
-#'                   barcode = c("TCGA-14-0736-02A-01R-2005-01", "TCGA-06-0211-02A-02R-2005-01"))
+#' query <- GDCquery(
+#'   project = "TCGA-GBM",
+#'   data.category = "Transcriptome Profiling",
+#'   data.type = "Gene Expression Quantification",
+#'   workflow.type = "STAR - Counts",
+#'   barcode = c("TCGA-14-0736-02A-01R-2005-01", "TCGA-06-0211-02A-02R-2005-01")
+#' )
 #' results <- getResults(query)
 getResults <- function(query, rows, cols){
     if(missing(cols) & missing(rows)) return(query$results[[1]])
