@@ -669,7 +669,11 @@ makeSEFromDNAMethylationMatrix <- function(
 
     rowRanges <- annotation[names(annotation) %in% rownames(betas),,drop = FALSE]
 
-    colData <-  DataFrame(samples = colnames(betas))
+    colData <- tryCatch({
+        colDataPrepare(colnames(betas))
+    }, error = function(e){
+        DataFrame(samples = colnames(betas))
+    })
     betas <- betas[rownames(betas) %in% names(rowRanges),,drop = FALSE]
     betas <- betas[names(rowRanges),,drop = FALSE]
     assay <- data.matrix(betas)
@@ -1503,10 +1507,16 @@ readTranscriptomeProfiling <- function(
             df <- data.table::rbindlist(
                 x, use.names = TRUE, idcol = "case_barcode"
             )
+
+            # Exception to the code below: CPTAC-3
+            # Sample barcode in CPTAC-3 does not handle duplicates
+            # we will need to work with aliquots for it or remove duplicated
+            # files. Example: C3N-02765-02
+
             if(!missing(cases))  {
                 df$case_barcode <- factor(
                     cases[df$case_barcode %>% as.numeric()],
-                    levels = cases
+                    levels = unique(cases)
                 )
             }
 
