@@ -26,17 +26,21 @@ datatable(
     caption = "List sample types"
 )
 
-## -----------------------------------------------------------------------------
-datatable(readr::read_csv("https://docs.google.com/spreadsheets/d/1f98kFdj9mxVDc1dv4xTZdx8iWgUiDYO-qiFJINvmTZs/export?format=csv&gid=2046985454",col_types = readr::cols()),
-          filter = 'top',
-          options = list(scrollX = TRUE, keys = TRUE, pageLength = 40), 
-          rownames = FALSE)
+## ---- echo=FALSE--------------------------------------------------------------
+datatable(
+    readr::read_csv("https://docs.google.com/spreadsheets/d/1f98kFdj9mxVDc1dv4xTZdx8iWgUiDYO-qiFJINvmTZs/export?format=csv&gid=2046985454",col_types = readr::cols()),
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 40), 
+    rownames = FALSE
+)
 
-## -----------------------------------------------------------------------------
-datatable(readr::read_csv("https://docs.google.com/spreadsheets/d/1f98kFdj9mxVDc1dv4xTZdx8iWgUiDYO-qiFJINvmTZs/export?format=csv&gid=1817673686",col_types = readr::cols()),
-          filter = 'top',
-          options = list(scrollX = TRUE, keys = TRUE, pageLength = 40), 
-          rownames = FALSE)
+## ---- echo=FALSE--------------------------------------------------------------
+datatable(
+    readr::read_csv("https://docs.google.com/spreadsheets/d/1f98kFdj9mxVDc1dv4xTZdx8iWgUiDYO-qiFJINvmTZs/export?format=csv&gid=1817673686",col_types = readr::cols()),
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 40), 
+    rownames = FALSE
+)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
 query <- GDCquery(
@@ -46,10 +50,12 @@ query <- GDCquery(
     platform = c("Illumina Human Methylation 450"),
     sample.type = "Recurrent Tumor"
 )
-datatable(getResults(query), 
-          filter = 'top',
-          options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
-          rownames = FALSE)
+datatable(
+    getResults(query), 
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
+    rownames = FALSE
+)
 
 ## ----message=FALSE, warning = FALSE, eval = FALSE-----------------------------
 #  query.met <- GDCquery(
@@ -62,7 +68,7 @@ datatable(getResults(query),
 #      project = "TCGA-COAD",
 #      data.category = "Transcriptome Profiling",
 #      data.type = "Gene Expression Quantification",
-#      workflow.type = "HTSeq - FPKM-UQ"
+#      workflow.type = "STAR - Counts"
 #  )
 #  
 #  # Get all patients that have DNA methylation and gene expression.
@@ -79,11 +85,12 @@ datatable(getResults(query),
 #      platform = c("Illumina Human Methylation 450"),
 #      barcode = common.patients[1:5]
 #  )
+#  
 #  query.exp <- GDCquery(
 #      project = "TCGA-COAD",
 #      data.category = "Transcriptome Profiling",
 #      data.type = "Gene Expression Quantification",
-#      workflow.type = "HTSeq - FPKM-UQ",
+#      workflow.type = "STAR - Counts",
 #      barcode = common.patients[1:5]
 #  )
 
@@ -103,13 +110,75 @@ datatable(getResults(query),
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
 query <- GDCquery(
-    project = c("TCGA-BRCA"),
-    data.category = "Sequencing Reads",  
-    sample.type = "Primary Tumor"
+    project = "TCGA-ACC", 
+    data.category = "Sequencing Reads",
+    data.type = "Aligned Reads", 
+    data.format = "bam",
+    workflow.type = "STAR 2-Pass Transcriptome"
 )
-# Only first 100 to make render faster
+# Only first 10 to make render faster
 datatable(
-    getResults(query, rows = 1:100,cols = c("file_name","cases")), 
+    getResults(query, rows = 1:10,cols = c("file_name","cases")), 
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
+    rownames = FALSE
+)
+
+query <- GDCquery(
+    project = "TCGA-ACC", 
+    data.category = "Sequencing Reads",
+    data.type = "Aligned Reads", 
+    data.format = "bam",
+    workflow.type = "STAR 2-Pass Genome"
+)
+# Only first 10 to make render faster
+datatable(
+    getResults(query, rows = 1:10,cols = c("file_name","cases")), 
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
+    rownames = FALSE
+)
+
+query <- GDCquery(
+    project = "TCGA-ACC", 
+    data.category = "Sequencing Reads",
+    data.type = "Aligned Reads", 
+    data.format = "bam",
+    workflow.type = "STAR 2-Pass Chimeric"
+)
+# Only first 10 to make render faster
+datatable(
+    getResults(query, rows = 1:10,cols = c("file_name","cases")), 
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
+    rownames = FALSE
+)
+
+query <- GDCquery(
+    project = "TCGA-ACC", 
+    data.category = "Sequencing Reads",
+    data.type = "Aligned Reads", 
+    data.format = "bam",
+    workflow.type = "BWA-aln"
+)
+# Only first 10 to make render faster
+datatable(
+    getResults(query, rows = 1:10,cols = c("file_name","cases")), 
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
+    rownames = FALSE
+)
+
+query <- GDCquery(
+    project = "TCGA-ACC", 
+    data.category = "Sequencing Reads",
+    data.type = "Aligned Reads", 
+    data.format = "bam",
+    workflow.type = "BWA with Mark Duplicates and BQSR"
+)
+# Only first 10 to make render faster
+datatable(
+    getResults(query, rows = 1:10,cols = c("file_name","cases")), 
     filter = 'top',
     options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
     rownames = FALSE
